Getting the Software

# XMLRésuméLibrary: User Guide

Setting up the XML Résumé Library | Setting up the XML Résumé Library | Installing and Configuring the Software

## Getting the Software

### XML Résumé Library

The XML Résumé Library is available for download at http://sourceforge.net/project/showfiles.php?group_id=29512 and is linked from the main XML Résumé Library page at http://xmlresume.sourceforge.net/.

### Xerces

Xerces is an XML parser, which is needed by the tools used in later steps of processing. It converts an XML document into a format that other computer programs can more easily use.

The main Xerces for Java2 page is http://xml.apache.org/xerces2-j/, with the download page at http://xml.apache.org/dist/xerces2-j/.

### Xalan

Xalan does the actual conversion of a résumé from XML to other formats. When combined with the XSL stylesheets provided by the XML Résumé Library, it produces directly usable HTML and plain text. It also produces an intermediate format called XSL-FO (XSL Formatting Objects) that can be converted to PDF by an FO processor.

The Xalan-Java project page is http://xml.apache.org/xalan-j/, with downloads at http://xml.apache.org/dist/xalan-j/.

### FOP

FOP is a print formatter for XSL formatting objects. It converts XSL-FO documents to PDF.

The main FOP page is http://xml.apache.org/fop/, and the download page is http://xml.apache.org/fop/download.html.

Setting up the XML Résumé Library | Setting up the XML Résumé Library | Installing and Configuring the Software